diff --git a/core/lib/Drupal/Component/Utility/UserAgent.php b/core/lib/Drupal/Component/Utility/UserAgent.php
index d91074b..8b35c75 100644
--- a/core/lib/Drupal/Component/Utility/UserAgent.php
+++ b/core/lib/Drupal/Component/Utility/UserAgent.php
@@ -106,7 +106,7 @@ public static function getBestMatchingLangcode($http_accept_language, $langcodes
       }
     }
 
-    // Find the enabled language with the greatest qvalue, following the rules
+    // Find the added language with the greatest qvalue, following the rules
     // of RFC 2616 (section 14.4). If several languages have the same qvalue,
     // prefer the one with the greatest weight.
     $best_match_langcode = FALSE;
diff --git a/core/lib/Drupal/Core/Language/LanguageManagerInterface.php b/core/lib/Drupal/Core/Language/LanguageManagerInterface.php
index da1a079..43b2f23 100644
--- a/core/lib/Drupal/Core/Language/LanguageManagerInterface.php
+++ b/core/lib/Drupal/Core/Language/LanguageManagerInterface.php
@@ -28,10 +28,10 @@ public function setTranslation(TranslationInterface $translation);
   public function init();
 
   /**
-   * Returns whether or not the site has more than one language enabled.
+   * Returns whether or not the site has more than one language added.
    *
    * @return bool
-   *   TRUE if more than one language is enabled, FALSE otherwise.
+   *   TRUE if more than one language is added, FALSE otherwise.
    */
   public function isMultilingual();
 
diff --git a/core/modules/content_translation/content_translation.install b/core/modules/content_translation/content_translation.install
index b814f2d..f6dda75 100644
--- a/core/modules/content_translation/content_translation.install
+++ b/core/modules/content_translation/content_translation.install
@@ -107,10 +107,10 @@ function content_translation_install() {
  * Implements hook_enable().
  */
 function content_translation_enable() {
-  // Translation works when at least two languages are enabled.
+  // Translation works when at least two languages are added.
   if (count(\Drupal::languageManager()->getLanguages()) < 2) {
     $t_args = array('!language_url' => url('admin/config/regional/language'));
-    $message = t('Be sure to <a href="!language_url">enable at least two languages</a> to translate content.', $t_args);
+    $message = t('Be sure to <a href="!language_url">add at least two languages</a> to translate content.', $t_args);
     drupal_set_message($message, 'warning');
   }
   // Point the user to the content translation settings.
diff --git a/core/modules/content_translation/lib/Drupal/content_translation/Tests/ContentTranslationTestBase.php b/core/modules/content_translation/lib/Drupal/content_translation/Tests/ContentTranslationTestBase.php
index 415b116..cec9404 100644
--- a/core/modules/content_translation/lib/Drupal/content_translation/Tests/ContentTranslationTestBase.php
+++ b/core/modules/content_translation/lib/Drupal/content_translation/Tests/ContentTranslationTestBase.php
@@ -38,7 +38,7 @@
   protected $bundle;
 
   /**
-   * The enabled languages.
+   * The added languages.
    *
    * @var array
    */
@@ -96,7 +96,7 @@ function setUp() {
   }
 
   /**
-   * Enables additional languages.
+   * Adds additional languages.
    */
   protected function setupLanguages() {
     $this->langcodes = array('it', 'fr');
diff --git a/core/modules/language/language.module b/core/modules/language/language.module
index 845407d..08cd8e0 100644
--- a/core/modules/language/language.module
+++ b/core/modules/language/language.module
@@ -60,7 +60,7 @@ function language_help($path, $arg) {
     case 'admin/structure/block/manage/%':
     case 'admin/structure/block/add/%/%':
       if ($arg[4] == 'language' && $arg[5] == 'language_interface') {
-        return '<p>' . t('With multiple languages enabled, registered users can select their preferred language and authors can assign a specific language to content.') . '</p>';
+        return '<p>' . t('With multiple languages added, registered users can select their preferred language and authors can assign a specific language to content.') . '</p>';
       }
       break;
 
diff --git a/core/modules/language/lib/Drupal/language/Plugin/LanguageNegotiation/LanguageNegotiationUrl.php b/core/modules/language/lib/Drupal/language/Plugin/LanguageNegotiation/LanguageNegotiationUrl.php
index eacb5c4..42a0933 100644
--- a/core/modules/language/lib/Drupal/language/Plugin/LanguageNegotiation/LanguageNegotiationUrl.php
+++ b/core/modules/language/lib/Drupal/language/Plugin/LanguageNegotiation/LanguageNegotiationUrl.php
@@ -59,7 +59,7 @@ public function getLangcode(Request $request = NULL) {
           $path_args = explode('/', $request_path);
           $prefix = array_shift($path_args);
 
-          // Search prefix within enabled languages.
+          // Search prefix within added languages.
           $negotiated_language = FALSE;
           foreach ($languages as $language) {
             if (isset($config['prefixes'][$language->id]) && $config['prefixes'][$language->id] == $prefix) {
@@ -104,7 +104,7 @@ public function processInbound($path, Request $request) {
     $parts = explode('/', $path);
     $prefix = array_shift($parts);
 
-    // Search prefix within enabled languages.
+    // Search prefix within added languages.
     foreach ($this->languageManager->getLanguages() as $language) {
       if (isset($config['prefixes'][$language->id]) && $config['prefixes'][$language->id] == $prefix) {
         // Rebuild $path with the language removed.
@@ -132,7 +132,7 @@ public function processOutbound($path, &$options = array(), Request $request = N
       $language_url = $this->languageManager->getCurrentLanguage(Language::TYPE_URL);
       $options['language'] = $language_url;
     }
-    // We allow only enabled languages here.
+    // We allow only added languages here.
     elseif (!is_object($options['language']) || !isset($languages[$options['language']->id])) {
       return $path;
     }
diff --git a/core/modules/language/lib/Drupal/language/Tests/LanguageListTest.php b/core/modules/language/lib/Drupal/language/Tests/LanguageListTest.php
index 273850b..d5abded 100644
--- a/core/modules/language/lib/Drupal/language/Tests/LanguageListTest.php
+++ b/core/modules/language/lib/Drupal/language/Tests/LanguageListTest.php
@@ -126,7 +126,7 @@ function testLanguageList() {
     $languages = $this->container->get('language_manager')->getLanguages();
     // We need raw here because %language and %langcode will add HTML.
     $t_args = array('%language' => 'French', '%langcode' => 'fr');
-    $this->assertRaw(t('The %language (%langcode) language has been removed.', $t_args), 'Disabled language has been removed.');
+    $this->assertRaw(t('The %language (%langcode) language has been removed.', $t_args), 'The French language has been removed.');
     $this->assertEqual($this->getUrl(), url('admin/config/regional/language', array('absolute' => TRUE)), 'Correct page redirection.');
     // Verify that language is no longer found.
     $this->drupalGet('admin/config/regional/language/delete/fr');
diff --git a/core/modules/language/lib/Drupal/language/Tests/LanguageUILanguageNegotiationTest.php b/core/modules/language/lib/Drupal/language/Tests/LanguageUILanguageNegotiationTest.php
index 169bfcf..1a2e5d6 100644
--- a/core/modules/language/lib/Drupal/language/Tests/LanguageUILanguageNegotiationTest.php
+++ b/core/modules/language/lib/Drupal/language/Tests/LanguageUILanguageNegotiationTest.php
@@ -32,7 +32,7 @@
  * 2. URL (PATH) > BROWSER > DEFAULT
  *        admin/config
  *          UI in user's browser language preference if the site has that
- *          language enabled, if not, the default language
+ *          language added, if not, the default language
  *        zh-hans/admin/config
  *          UI in Chinese
  *        blah-blah/admin/config
diff --git a/core/modules/node/lib/Drupal/node/NodeListBuilder.php b/core/modules/node/lib/Drupal/node/NodeListBuilder.php
index 51b2485..fc9c0ba 100644
--- a/core/modules/node/lib/Drupal/node/NodeListBuilder.php
+++ b/core/modules/node/lib/Drupal/node/NodeListBuilder.php
@@ -61,7 +61,7 @@ public static function createInstance(ContainerInterface $container, EntityTypeI
    * {@inheritdoc}
    */
   public function buildHeader() {
-    // Enable language column and filter if multiple languages are enabled.
+    // Enable language column and filter if multiple languages are added.
     $header = array(
       'title' => $this->t('Title'),
       'type' => array(
diff --git a/core/modules/search/lib/Drupal/search/Tests/SearchLanguageTest.php b/core/modules/search/lib/Drupal/search/Tests/SearchLanguageTest.php
index c7b51c8..7cdf0bd 100644
--- a/core/modules/search/lib/Drupal/search/Tests/SearchLanguageTest.php
+++ b/core/modules/search/lib/Drupal/search/Tests/SearchLanguageTest.php
@@ -25,7 +25,7 @@ class SearchLanguageTest extends SearchTestBase {
   public static function getInfo() {
     return array(
       'name' => 'Search language selection',
-      'description' => 'Tests advanced search with different languages enabled.',
+      'description' => 'Tests advanced search with different languages added.',
       'group' => 'Search',
     );
   }
diff --git a/core/modules/views/lib/Drupal/views/Tests/Entity/RowEntityRenderersTest.php b/core/modules/views/lib/Drupal/views/Tests/Entity/RowEntityRenderersTest.php
index 1694fd0..82d7c4d 100644
--- a/core/modules/views/lib/Drupal/views/Tests/Entity/RowEntityRenderersTest.php
+++ b/core/modules/views/lib/Drupal/views/Tests/Entity/RowEntityRenderersTest.php
@@ -33,7 +33,7 @@ class RowEntityRenderersTest extends ViewUnitTestBase {
   public static $testViews = array('test_entity_row_renderers');
 
   /**
-   * An array of enabled languages.
+   * An array of added languages.
    *
    * @var array
    */
diff --git a/sites/default/default.settings.php b/sites/default/default.settings.php
index b2ce930..9fa9dde 100644
--- a/sites/default/default.settings.php
+++ b/sites/default/default.settings.php
@@ -491,7 +491,7 @@
  * Remove the leading hash signs to enable.
  *
  * The "en" part of the variable name, is dynamic and can be any langcode of
- * any enabled language. (eg locale_custom_strings_de for german).
+ * any added language. (eg locale_custom_strings_de for german).
  */
 # $settings['locale_custom_strings_en'][''] = array(
 #   'forum'      => 'Discussion board',

diff --git a/core/modules/user/lib/Drupal/user/AccountForm.php b/core/modules/user/lib/Drupal/user/AccountForm.php
index f85fca2..f650c07 100644
--- a/core/modules/user/lib/Drupal/user/AccountForm.php
+++ b/core/modules/user/lib/Drupal/user/AccountForm.php
@@ -237,11 +237,11 @@ public function form(array $form, array &$form_state) {
 
     $user_preferred_admin_langcode = $register ? $language_interface->id : $account->getPreferredAdminLangcode();
 
-    // Is the user preferred language enabled?
-    $user_language_enabled = FALSE;
+    // Is the user preferred language added?
+    $user_language_added = FALSE;
     if ($this->languageManager instanceof ConfigurableLanguageManagerInterface) {
       $negotiator = $this->languageManager->getNegotiator();
-      $user_language_enabled = $negotiator && $negotiator->isNegotiationMethodEnabled(LanguageNegotiationUser::METHOD_ID, Language::TYPE_INTERFACE);
+      $user_language_added = $negotiator && $negotiator->isNegotiationMethodEnabled(LanguageNegotiationUser::METHOD_ID, Language::TYPE_INTERFACE);
     }
     $form['language'] = array(
       '#type' => $this->languageManager->isMultilingual() ? 'details' : 'container',
@@ -257,7 +257,7 @@ public function form(array $form, array &$form_state) {
       '#title' => $this->t('Site language'),
       '#languages' => Language::STATE_CONFIGURABLE,
       '#default_value' => $user_preferred_langcode,
-      '#description' => $user_language_enabled ? $this->t("This account's preferred language for e-mails and site presentation.") : $this->t("This account's preferred language for e-mails."),
+      '#description' => $user_language_added ? $this->t("This account's preferred language for e-mails and site presentation.") : $this->t("This account's preferred language for e-mails."),
     );
 
     // Only show the account setting for Administration pages language to users